@@ -55,15 +55,16 @@ our @EXPORT_OK = qw(
     create_from_ref
     create_from_hash
     create_from_array
+    create_from_string
 );
 
 our %EXPORT_TAGS = (
     all    => \@EXPORT_OK,
-    create => [ qw(create_from_ref create_from_hash create_from_array plist_as_string) ],
+    create => [ qw(create_from_ref create_from_hash create_from_array create_from_string plist_as_string) ],
     parse  => [ qw(parse_plist parse_plist_fh parse_plist_file parse_plist_string) ],
 );
 
-our $VERSION = '0.86';
+our $VERSION = '0.90';
 
 
 
@@ -239,9 +240,9 @@ sub create_from_ref {
         else { Mac::PropertyList::SAX::string->new($OLD_BEHAVIOR ? _escape($val) : $val)->write }
     }
 
-    $Mac::PropertyList::XML_head .
+    Mac::PropertyList::XML_head() .
         (join "\n", _handle_value(shift)) . "\n" .
-        $Mac::PropertyList::XML_foot;
+        Mac::PropertyList::XML_foot();
 }
 
 =item create_from_hash( HASH_REF )
@@ -262,6 +263,14 @@ create_from_ref.
 
 *create_from_array = \&create_from_ref;
 
+=item create_from_string( STRING )
+
+Provided for backward compatibility with L<Mac::PropertyList|Mac::PropertyList>: aliases C<Mac::PropertyList::create_from_string()>.
+
+=cut
+
+*create_from_string = \&Mac::PropertyList::create_from_string;
+
 =item _escape( STRING )
 
 B<Internal use only.> Escapes illegal characters into XML entities.
